"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _plugin = _interopRequireDefault(require("@ckeditor/ckeditor5-core/src/plugin"));

var _utils = require("@ckeditor/ckeditor5-widget/src/utils");

var _widget = _interopRequireDefault(require("@ckeditor/ckeditor5-widget/src/widget"));

var _insertcodesnippetcommand = _interopRequireDefault(require("./insertcodesnippetcommand"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class CodeSnippetEditing extends _plugin.default {
  static get requires() {
    return [_widget.default];
  }

  init() {
    this._defineSchema();

    this._defineConverters();

    this.editor.commands.add('insertCodeSnippet', new _insertcodesnippetcommand.default(this.editor));
  }

  _defineSchema() {
    const schema = this.editor.model.schema;
    schema.register('codeSnippet', {
      // Cannot be split or left by the caret.
      isLimit: true,
      // Allow in places where other blocks are allowed (e.g. directly in the root).
      allowWhere: '$block',
      // Allow only block content
      allowContentOf: ['$block', '$text']
    });
  }

  _defineConverters() {
    const conversion = this.editor.conversion;
    conversion.for('upcast').elementToElement({
      model: 'codeSnippet',
      view: {
        name: 'pre',
        classes: 'code-snippet'
      }
    });
    conversion.for('dataDowncast').elementToElement({
      model: 'codeSnippet',
      view: {
        name: 'pre',
        classes: 'code-snippet'
      }
    });
    conversion.for('editingDowncast').elementToElement({
      model: 'codeSnippet',
      view: (modelElement, viewWriter) => {
        const pre = viewWriter.createEditableElement('pre', {
          class: 'code-snippet'
        });
        return (0, _utils.toWidgetEditable)(pre, viewWriter, {
          label: 'code snippet widget'
        });
      }
    });
  }

}

exports.default = CodeSnippetEditing;